@@ -342,9 +342,9 @@ class ExecResult:
     ]
     score: Optional[float]
     hold_bars: Optional[int]
-    buy_shares: Optional[int]
+    buy_shares: Optional[Union[int, float, Decimal]]
     buy_limit_price: Optional[Decimal]
-    sell_shares: Optional[int]
+    sell_shares: Optional[Union[int, float, Decimal]]
     sell_limit_price: Optional[Decimal]
 
 
@@ -364,7 +364,7 @@ class ExecSignal(NamedTuple):
 
     id: int
     symbol: str
-    shares: int
+    shares: Union[int, float, Decimal]
     score: Optional[float]
     bar_data: BarData
     type: Literal["buy", "sell"]
@@ -397,7 +397,7 @@ class PosSizeContext(BaseContext):
             models=models,
             sym_end_index=sym_end_index,
         )
-        self._signal_shares: dict[int, int] = {}
+        self._signal_shares: dict[int, Union[int, float, Decimal]] = {}
         self._buy_results: Optional[list[ExecResult]] = None
         self._sell_results: Optional[list[ExecResult]] = None
         self._max_long_positions = max_long_positions
@@ -460,7 +460,9 @@ class PosSizeContext(BaseContext):
                 ):
                     break
 
-    def set_shares(self, signal: ExecSignal, shares: int):
+    def set_shares(
+        self, signal: ExecSignal, shares: Union[int, float, Decimal]
+    ):
         """Sets the number of shares of an order for the buy or sell signal."""
         self._signal_shares[signal.id] = shares
 
@@ -553,7 +555,7 @@ class ExecContext(BaseContext):
             PriceType,
             Callable[[BarData], Union[int, float, Decimal, str]],
         ] = PriceType.MIDDLE
-        self.buy_shares: Optional[int] = None
+        self.buy_shares: Optional[Union[int, float, Decimal]] = None
         self.buy_limit_price: Optional[Union[int, float, Decimal, str]] = None
         self.sell_fill_price: Union[
             int,
@@ -563,12 +565,16 @@ class ExecContext(BaseContext):
             PriceType,
             Callable[[BarData], Union[int, float, Decimal, str]],
         ] = PriceType.MIDDLE
-        self.sell_shares: Optional[int] = None
+        self.sell_shares: Optional[Union[int, float, Decimal]] = None
         self.sell_limit_price: Optional[Union[int, float, Decimal, str]] = None
         self.hold_bars: Optional[int] = None
         self.score: Optional[float] = None
         self.session: Optional[dict] = None
 
+    def _verify_symbol(self):
+        if self.symbol is None:
+            raise ValueError("symbol is not set.")
+
     @property
     def dt(self) -> datetime:
         """Current bar's date expressed as a ``datetime``."""
@@ -581,64 +587,71 @@ class ExecContext(BaseContext):
     @property
     def date(self) -> NDArray[np.datetime64]:
         """Current bar's date expressed as a ``numpy.datetime64``."""
-        if self.symbol is None:
-            raise ValueError("symbol is not set.")
+        self._verify_symbol()
         return self._col_scope.fetch(  # type: ignore[return-value]
-            self.symbol, DataCol.DATE.value, self._end_index
+            self.symbol,  # type: ignore[arg-type]
+            DataCol.DATE.value,
+            self._end_index,
         )
 
     @property
     def open(self) -> NDArray[np.float_]:
         """Current bar's open price."""
-        if self.symbol is None:
-            raise ValueError("symbol is not set.")
+        self._verify_symbol()
         return self._col_scope.fetch(  # type: ignore[return-value]
-            self.symbol, DataCol.OPEN.value, self._end_index
+            self.symbol,  # type: ignore[arg-type]
+            DataCol.OPEN.value,
+            self._end_index,
         )
 
     @property
     def high(self) -> NDArray[np.float_]:
         """Current bar's high price."""
-        if self.symbol is None:
-            raise ValueError("symbol is not set.")
+        self._verify_symbol()
         return self._col_scope.fetch(  # type: ignore[return-value]
-            self.symbol, DataCol.HIGH.value, self._end_index
+            self.symbol,  # type: ignore[arg-type]
+            DataCol.HIGH.value,
+            self._end_index,
         )
 
     @property
     def low(self) -> NDArray[np.float_]:
         """Current bar's low price."""
-        if self.symbol is None:
-            raise ValueError("symbol is not set.")
+        self._verify_symbol()
         return self._col_scope.fetch(  # type: ignore[return-value]
-            self.symbol, DataCol.LOW.value, self._end_index
+            self.symbol,  # type: ignore[arg-type]
+            DataCol.LOW.value,
+            self._end_index,
         )
 
     @property
     def close(self) -> NDArray[np.float_]:
         """Current bar's close price."""
-        if self.symbol is None:
-            raise ValueError("symbol is not set.")
+        self._verify_symbol()
         return self._col_scope.fetch(  # type: ignore[return-value]
-            self.symbol, DataCol.CLOSE.value, self._end_index
+            self.symbol,  # type: ignore[arg-type]
+            DataCol.CLOSE.value,
+            self._end_index,
         )
 
     @property
     def volume(self) -> Optional[NDArray[np.float_]]:
         """Current bar's volume."""
-        if self.symbol is None:
-            raise ValueError("symbol is not set.")
+        self._verify_symbol()
         return self._col_scope.fetch(  # type: ignore[return-value]
-            self.symbol, DataCol.VOLUME.value, self._end_index
+            self.symbol,  # type: ignore[arg-type]
+            DataCol.VOLUME.value,
+            self._end_index,
         )
 
     @property
     def vwap(self) -> Optional[NDArray[np.float_]]:
         """Current bar's volume-weighted average price (VWAP)."""
-        if self.symbol is None:
-            raise ValueError("symbol is not set.")
+        self._verify_symbol()
         return self._col_scope.fetch(  # type: ignore[return-value]
-            self.symbol, DataCol.VWAP.value, self._end_index
+            self.symbol,  # type: ignore[arg-type]
+            DataCol.VWAP.value,
+            self._end_index,
         )
 
     def sell_all_shares(self):
