@@ -38,7 +38,7 @@ from .context import (
     set_exec_ctx_data,
     set_pos_size_ctx_data,
 )
-from .data import DataSource
+from .data import AlpacaCrypto, DataSource
 from .eval import BootstrapResult, EvalMetrics, EvaluateMixin
 from .indicator import Indicator, IndicatorsMixin
 from .model import ModelSource, ModelsMixin, TrainedModel
@@ -996,6 +996,7 @@ class Strategy(
                 resolution of the backtesting data. The timeframe string
                 supports the following units:
 
+                - ``"s"``/``"sec"``: seconds
                 - ``"m"``/``"min"``: minutes
                 - ``"h"``/``"hour"``: hours
                 - ``"d"``/``"day"``: days
@@ -1078,6 +1079,7 @@ class Strategy(
                 resolution of the backtesting data. The timeframe string
                 supports the following units:
 
+                - ``"s"``/``"sec"``: seconds
                 - ``"m"``/``"min"``: minutes
                 - ``"h"``/``"hour"``: hours
                 - ``"d"``/``"day"``: days
@@ -1196,6 +1198,11 @@ class Strategy(
             )
         )  # type: ignore[return-value]
 
+    def _fractional_shares_enabled(self):
+        return self._config.enable_fractional_shares or isinstance(
+            self._data_source, AlpacaCrypto
+        )
+
     def _run_walkfoward(
         self,
         df: pd.DataFrame,
@@ -1219,6 +1226,7 @@ class Strategy(
             self._config.initial_cash,
             self._config.fee_mode,
             self._config.fee_amount,
+            self._fractional_shares_enabled(),
             self._config.max_long_positions,
             self._config.max_short_positions,
         )
@@ -1366,8 +1374,6 @@ class Strategy(
             "unrealized_pnl",
         ):
             pos_df[col] = quantize(pos_df, col)
-        pos_df["long_shares"] = pos_df["long_shares"].astype(int)
-        pos_df["short_shares"] = pos_df["short_shares"].astype(int)
         pos_df.set_index(["symbol", "date"], inplace=True)
         portfolio_df = pd.DataFrame.from_records(
             portfolio_bars, columns=PortfolioBar._fields, index="date"
@@ -1385,16 +1391,26 @@ class Strategy(
         orders_df = pd.DataFrame.from_records(
             orders, columns=Order._fields, index="id"
         )
-        orders_df["shares"] = orders_df["shares"].astype(int)
         for col in ("limit_price", "fill_price", "fees"):
             orders_df[col] = quantize(orders_df, col)
         trades_df = pd.DataFrame.from_records(
             trades, columns=Trade._fields, index="id"
         )
-        trades_df["shares"] = trades_df["shares"].astype(int)
         trades_df["bars"] = trades_df["bars"].astype(int)
-        for col in ("pnl", "return_pct", "cumulative_pnl", "pnl_per_bar"):
+        for col in (
+            "entry",
+            "exit",
+            "pnl",
+            "return_pct",
+            "agg_pnl",
+            "pnl_per_bar",
+        ):
             trades_df[col] = quantize(trades_df, col)
+        shares_type = float if self._fractional_shares_enabled() else int
+        pos_df["long_shares"] = pos_df["long_shares"].astype(shares_type)
+        pos_df["short_shares"] = pos_df["short_shares"].astype(shares_type)
+        orders_df["shares"] = orders_df["shares"].astype(shares_type)
+        trades_df["shares"] = trades_df["shares"].astype(shares_type)
         eval_result = self.evaluate(
             portfolio_df=portfolio_df,
             trades_df=trades_df,
